@@ -290,7 +290,9 @@ struct CLIENT_STATE {
         // wait until at least this time to try running
         // another task that needs a shared-mem seg
     inline double work_buf_min() {
-        return global_prefs.work_buf_min_days * 86400;
+        double x = global_prefs.work_buf_min_days * 86400;
+        if (x < 180) x = 180;
+        return x;
     }
     inline double work_buf_additional() {
         return global_prefs.work_buf_additional_days *86400;
@@ -373,9 +375,12 @@ struct CLIENT_STATE {
     bool is_supported_platform(const char*);
 
 // --------------- cs_prefs.cpp:
-    int project_disk_usage(PROJECT*, double&);
-    int total_disk_usage(double&);
-        // returns the total disk usage of BOINC on this host
+    double client_disk_usage;
+        // disk usage not counting projects
+        // computed by get_disk_usages()
+    double total_disk_usage;
+    int get_disk_usages();
+    void get_disk_shares();
     double allowed_disk_usage(double boinc_total);
     int allowed_project_disk_usage(double&);
     int suspend_tasks(int reason);
