@@ -131,6 +131,26 @@ int FILE_INFO::verify_file(bool strict, bool show_errors) {
 
     get_pathname(this, pathname, sizeof(pathname));
 
+    strcpy(cksum, "");
+
+    // see if we need to unzip it
+    //
+    if (download_gzipped && !boinc_file_exists(pathname)) {
+        char gzpath[256];
+        sprintf(gzpath, "%s.gz", pathname);
+        if (boinc_file_exists(gzpath) ) {
+            retval = gunzip(cksum);
+            if (retval) return retval;
+        } else {
+            strcat(gzpath, "t");
+            if (!boinc_file_exists(gzpath)) {
+                status = FILE_NOT_PRESENT;
+            }
+            return ERR_FILE_MISSING;
+        }
+    }
+
+
     // If the file isn't there at all, set status to FILE_NOT_PRESENT;
     // this will trigger a new download rather than erroring out
     //
@@ -184,7 +204,8 @@ int FILE_INFO::verify_file(bool strict, bool show_errors) {
             return ERR_NO_SIGNATURE;
         }
         retval = verify_file2(
-            pathname, file_signature, project->code_sign_key, verified
+            pathname, strlen(cksum)?cksum:NULL,
+            file_signature, project->code_sign_key, verified
         );
         if (retval) {
             msg_printf(project, MSG_INTERNAL_ERROR,
@@ -205,15 +226,17 @@ int FILE_INFO::verify_file(bool strict, bool show_errors) {
             return ERR_RSA_FAILED;
         }
     } else if (strlen(md5_cksum)) {
-        retval = md5_file(pathname, cksum, local_nbytes);
-        if (retval) {
-            msg_printf(project, MSG_INTERNAL_ERROR,
-                "MD5 computation error for %s: %s\n",
-                name, boincerror(retval)
-            );
-            error_msg = "MD5 computation error";
-            status = retval;
-            return retval;
+        if (!strlen(cksum)) {
+            retval = md5_file(pathname, cksum, local_nbytes);
+            if (retval) {
+                msg_printf(project, MSG_INTERNAL_ERROR,
+                    "MD5 computation error for %s: %s\n",
+                    name, boincerror(retval)
+                );
+                error_msg = "MD5 computation error";
+                status = retval;
+                return retval;
+            }
         }
         if (strcmp(cksum, md5_cksum)) {
             if (show_errors) {
@@ -295,6 +318,16 @@ bool CLIENT_STATE::create_and_delete_pers_file_xfers() {
             } else if (fip->status >= 0) {
                 // file transfer did not fail (non-negative status)
 
+                // If this was a compressed download, rename .gzt to .gz
+                //
+                if (fip->download_gzipped) {
+                    char path[256], from_path[256], to_path[256];
+                    get_pathname(fip, path, sizeof(path));
+                    sprintf(from_path, "%s.gzt", path);
+                    sprintf(to_path, "%s.gz", path);
+                    boinc_rename(from_path, to_path);
+                }
+
                 // verify the file with RSA or MD5, and change permissions
                 //
                 retval = fip->verify_file(true, true);
