@@ -107,13 +107,15 @@ echo
         show_dir(1, 'projects', $mp0770, array(
             show_dir(2, 'setiathome.berkeley.edu', $mp0775, array(
                 show_file('files created by BOINC Client', $mp06610771),
-                show_file('files created by project apps', $pp06610771)
+                show_file('files created by project apps', $pp06610771),
+                show_file('running BOINC installer changes all files to', $mp06610771)
             ))
         )),
         show_dir(1, 'slots', $mp0770, array(
             show_dir(2, '0', $mp0775, array(
                 show_file('files created by BOINC Client', $mp06610771),
-                show_file('files created by project apps', $pp06610771)
+                show_file('files created by project apps', $pp06610771),
+                show_file('running BOINC installer changes all files to', $mp06610771)
             ))
         )),
         show_dir(1, 'switcher (directory)', $mm0550, array(
@@ -264,6 +266,17 @@ BOINC tree diagram shown above.
 can perform BOINC Manager functions (Activity Menu, etc.).
 This can be done by moving BOINC Manager out of the
 <b>/Applications</b> directory into a directory with restricted access.
+<li><b>Important information for project developers:</b> The BOINC 
+installer traverses the BOINC Data directory and sets the users, groups and 
+permissions of all files as shown in the above table.  This allows it to 
+repair corrupted permissions.  <b>Note</b> that the BOINC installer will 
+<b>change all files</b> in the projects directory, the slots directory, and 
+all their subdirectories to <b>user boinc_master</b> and 
+<b>group boinc_project</b>.  This means that if a project file needs to be 
+executable by another project file, its executable-by-group permission bit 
+<b>must</b> be set.  The BOINC installer will <i>not</i> alter the 
+executable-by-user and executable-by-group permission bits of files in these 
+directories (though it will set these bits for the directories themselves.)
 </ul>
 </p>
 ";
