@@ -118,6 +118,7 @@ void APP_INIT_DATA::copy(const APP_INIT_DATA& a) {
     fraction_done_start           = a.fraction_done_start;
     fraction_done_end             = a.fraction_done_end;
     gpu_device_num                = a.gpu_device_num;
+    gpu_opencl_dev_index          = a.gpu_opencl_dev_index;
     ncpus                         = a.ncpus;
     checkpoint_period             = a.checkpoint_period;
     wu_cpu_time                   = a.wu_cpu_time;
@@ -204,6 +205,7 @@ int write_init_data_file(FILE* f, APP_INIT_DATA& ai) {
         "<fraction_done_end>%f</fraction_done_end>\n"
         "<gpu_type>%s</gpu_type>\n"
         "<gpu_device_num>%d</gpu_device_num>\n"
+        "<gpu_opencl_dev_index>%d</gpu_opencl_dev_index>\n"
         "<ncpus>%f</ncpus>\n"
         "<rsc_fpops_est>%f</rsc_fpops_est>\n"
         "<rsc_fpops_bound>%f</rsc_fpops_bound>\n"
@@ -224,6 +226,7 @@ int write_init_data_file(FILE* f, APP_INIT_DATA& ai) {
         ai.fraction_done_end,
         ai.gpu_type,
         ai.gpu_device_num,
+        ai.gpu_opencl_dev_index,
         ai.ncpus,
         ai.rsc_fpops_est,
         ai.rsc_fpops_bound,
@@ -280,6 +283,8 @@ void APP_INIT_DATA::clear() {
     checkpoint_period = 0;
     strcpy(gpu_type, "");
     gpu_device_num = 0;
+    // -1 means an older version without gpu_opencl_dev_index field
+    gpu_opencl_dev_index = -1;
     ncpus = 0;
     memset(&shmem_seg_name, 0, sizeof(shmem_seg_name));
     wu_cpu_time = 0;
@@ -378,6 +383,7 @@ int parse_init_data_file(FILE* f, APP_INIT_DATA& ai) {
         if (xp.parse_double("checkpoint_period", ai.checkpoint_period)) continue;
         if (xp.parse_str("gpu_type", ai.gpu_type, sizeof(ai.gpu_type))) continue;
         if (xp.parse_int("gpu_device_num", ai.gpu_device_num)) continue;
+        if (xp.parse_int("gpu_opencl_dev_index", ai.gpu_opencl_dev_index)) continue;
         if (xp.parse_double("ncpus", ai.ncpus)) continue;
         if (xp.parse_double("fraction_done_start", ai.fraction_done_start)) continue;
         if (xp.parse_double("fraction_done_end", ai.fraction_done_end)) continue;
