@@ -101,10 +101,10 @@ extern int sign_block(
     DATA_BLOCK& data, R_RSA_PRIVATE_KEY&, DATA_BLOCK& signature
 );
 extern int verify_file(
-    const char* path, R_RSA_PUBLIC_KEY&, DATA_BLOCK& signature, bool&
+    const char* path, const char* md5, R_RSA_PUBLIC_KEY&, DATA_BLOCK& signature, bool&
 );
 extern int verify_file2(
-    const char* path, const char* signature, const char* key, bool&
+    const char* path, const char* md5, const char* signature, const char* key, bool&
 );
 extern int verify_string(
     const char* text, const char* signature, R_RSA_PUBLIC_KEY&, bool&
