@@ -10,13 +10,13 @@
 #define BOINC_MINOR_VERSION 0
 
 /* Release part of BOINC version number */
-#define BOINC_RELEASE 11
+#define BOINC_RELEASE 14
 
 /* String representation of BOINC version number */
-#define BOINC_VERSION_STRING "7.0.11"
+#define BOINC_VERSION_STRING "7.0.14"
 
 /* Package is a pre-release (Alpha/Beta) package */
-#define BOINC_PRERELEASE 1
+/* #define BOINC_PRERELEASE 1 */
 
 #if (defined(_WIN32) || defined(__APPLE__))
 /* Name of package */
@@ -29,13 +29,13 @@
 #define PACKAGE_NAME "BOINC"
 
 /* Define to the full name and version of this package. */
-#define PACKAGE_STRING "BOINC 7.0.11"
+#define PACKAGE_STRING "BOINC 7.0.14"
 
 /* Define to the one symbol short name of this package. */
 #define PACKAGE_TARNAME "boinc"
 
 /* Define to the version of this package. */
-#define PACKAGE_VERSION "7.0.11"
+#define PACKAGE_VERSION "7.0.14"
 
 #endif /* #if (defined(_WIN32) || defined(__APPLE__)) */
 
