@@ -862,10 +862,13 @@ char *zip;              /* path name of zip file to generate temp name for */
 #ifdef _WIN32
   return mktemp(t);
 #else
-  if (mkstemp(t))
-    return t;
-  else
-    return NULL;
+    int fd = mkstemp(t);
+    if (fd) {
+        close(fd);
+        return t;
+    } else {
+        return NULL; 
+    }
 #endif /* MKSTEMP */
 #endif /* NO_MKTEMP */
 #endif /* TANDEM */
@@ -990,4 +993,4 @@ register unsigned int len;
 
 #endif  /* ZMEM */
 
-const char *BOINC_RCSID_cd0cef87cc = "$Id: z_fileio.c 4979 2005-01-02 18:29:53Z ballen $";
+const char *BOINC_RCSID_cd0cef87cc = "$Id: z_fileio.c 14563 2008-01-16 04:43:19Z davea $";
